Ray

Struct Ray 

pub struct Ray<V: VectorSpace> {
    pub origin: V,
    pub direction: V,
}
A ray defined by an origin point and a direction vector.

Fields

origin: V

The starting point of the ray.

direction: V

The direction the ray extends in.

Implementations

Source

impl<V: Copy + InnerSpace> Ray<V>

pub fn new(origin: V, direction: V) -> Self

Creates a new ray.

pub fn intersect_sphere( &self, center: V, radius: V::Scalar, ) -> Option<(V::Scalar, CollisionInfo<V>)>

Intersects this ray with a sphere defined by center and radius. Returns the ray parameter and collision info if the ray hits the sphere.