Ray collider implementation for the collide crate.
A ray is defined by an origin and a direction vector. It extends infinitely in the direction from the origin.
Structs
- Ray
- A ray defined by an origin point and a direction vector.