pub struct Ray<V: VectorSpace> {
pub origin: V,
pub direction: V,
}Expand description
A ray defined by an origin point and a direction vector.
Fields
origin: VThe starting point of the ray.
direction: VThe direction the ray extends in.
Implementations
Sourceimpl<V: Copy + InnerSpace> Ray<V>
impl<V: Copy + InnerSpace> Ray<V>
Sourcepub fn intersect_sphere(
&self,
center: V,
radius: V::Scalar,
) -> Option<(V::Scalar, CollisionInfo<V>)>
pub fn intersect_sphere( &self, center: V, radius: V::Scalar, ) -> Option<(V::Scalar, CollisionInfo<V>)>
Intersects this ray with a sphere defined by center and radius. Returns the ray parameter and collision info if the ray hits the sphere.